==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/MediaContentRatingAustralia.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

import odata.msgraph.client.beta.enums.RatingAustraliaMoviesType;
import odata.msgraph.client.beta.enums.RatingAustraliaTelevisionType;

@JsonPropertyOrder({
    "@odata.type", 
    "movieRating", 
    "tvRating"})
@JsonInclude(Include.NON_NULL)
public class MediaContentRatingAustralia implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("movieRating")
    protected RatingAustraliaMoviesType movieRating;

    @JsonProperty("tvRating")
    protected RatingAustraliaTelevisionType tvRating;

    protected MediaContentRatingAustralia() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.mediaContentRatingAustralia";
    }

    /**
     * <i>“Movies rating selected for Australia”</i>
     * 
     * @return property movieRating
     */
    @Property(name="movieRating")
    @JsonIgnore
    public Optional<RatingAustraliaMoviesType> getMovieRating() {
        return Optional.ofNullable(movieRating);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code movieRating}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“Movies rating selected for Australia”</i>
     * 
     * @param movieRating
     *            new value of {@code movieRating} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code movieRating} field changed
     */
    public MediaContentRatingAustralia withMovieRating(RatingAustraliaMoviesType movieRating) {
        MediaContentRatingAustralia _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mediaContentRatingAustralia");
        _x.movieRating = movieRating;
        return _x;
    }

    /**
     * <i>“TV rating selected for Australia”</i>
     * 
     * @return property tvRating
     */
    @Property(name="tvRating")
    @JsonIgnore
    public Optional<RatingAustraliaTelevisionType> getTvRating() {
        return Optional.ofNullable(tvRating);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code tvRating} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“TV rating selected for Australia”</i>
     * 
     * @param tvRating
     *            new value of {@code tvRating} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code tvRating} field changed
     */
    public MediaContentRatingAustralia withTvRating(RatingAustraliaTelevisionType tvRating) {
        MediaContentRatingAustralia _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mediaContentRatingAustralia");
        _x.tvRating = tvRating;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private RatingAustraliaMoviesType movieRating;
        private RatingAustraliaTelevisionType tvRating;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        /**
         * <i>“Movies rating selected for Australia”</i>
         * 
         * @param movieRating
         *            value of {@code movieRating} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder movieRating(RatingAustraliaMoviesType movieRating) {
            this.movieRating = movieRating;
            this.changedFields = changedFields.add("movieRating");
            return this;
        }

        /**
         * <i>“TV rating selected for Australia”</i>
         * 
         * @param tvRating
         *            value of {@code tvRating} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder tvRating(RatingAustraliaTelevisionType tvRating) {
            this.tvRating = tvRating;
            this.changedFields = changedFields.add("tvRating");
            return this;
        }

        public MediaContentRatingAustralia build() {
            MediaContentRatingAustralia _x = new MediaContentRatingAustralia();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.mediaContentRatingAustralia";
            _x.movieRating = movieRating;
            _x.tvRating = tvRating;
            return _x;
        }
    }

    private MediaContentRatingAustralia _copy() {
        MediaContentRatingAustralia _x = new MediaContentRatingAustralia();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.movieRating = movieRating;
        _x.tvRating = tvRating;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("MediaContentRatingAustralia[");
        b.append("movieRating=");
        b.append(this.movieRating);
        b.append(", ");
        b.append("tvRating=");
        b.append(this.tvRating);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/MediaContentRatingAustralia.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

import odata.msgraph.client.beta.enums.RatingAustraliaMoviesType;
import odata.msgraph.client.beta.enums.RatingAustraliaTelevisionType;

@JsonPropertyOrder({
    "@odata.type", 
    "movieRating", 
    "tvRating"})
@JsonInclude(Include.NON_NULL)
public class MediaContentRatingAustralia implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("movieRating")
    protected RatingAustraliaMoviesType movieRating;

    @JsonProperty("tvRating")
    protected RatingAustraliaTelevisionType tvRating;

    protected MediaContentRatingAustralia() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.mediaContentRatingAustralia";
    }

    /**
     * <i>“Movies rating selected for Australia”</i>
     * 
     * @return property movieRating
     */
    @Property(name="movieRating")
    @JsonIgnore
    public Optional<RatingAustraliaMoviesType> getMovieRating() {
        return Optional.ofNullable(movieRating);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code movieRating}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“Movies rating selected for Australia”</i>
     * 
     * @param movieRating
     *            new value of {@code movieRating} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code movieRating} field changed
     */
    public MediaContentRatingAustralia withMovieRating(RatingAustraliaMoviesType movieRating) {
        MediaContentRatingAustralia _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mediaContentRatingAustralia");
        _x.movieRating = movieRating;
        return _x;
    }

    /**
     * <i>“TV rating selected for Australia”</i>
     * 
     * @return property tvRating
     */
    @Property(name="tvRating")
    @JsonIgnore
    public Optional<RatingAustraliaTelevisionType> getTvRating() {
        return Optional.ofNullable(tvRating);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code tvRating} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“TV rating selected for Australia”</i>
     * 
     * @param tvRating
     *            new value of {@code tvRating} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code tvRating} field changed
     */
    public MediaContentRatingAustralia withTvRating(RatingAustraliaTelevisionType tvRating) {
        MediaContentRatingAustralia _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mediaContentRatingAustralia");
        _x.tvRating = tvRating;
        return _x;
    }

    public MediaContentRatingAustralia withUnmappedField(String name, Object value) {
        MediaContentRatingAustralia _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private RatingAustraliaMoviesType movieRating;
        private RatingAustraliaTelevisionType tvRating;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        /**
         * <i>“Movies rating selected for Australia”</i>
         * 
         * @param movieRating
         *            value of {@code movieRating} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder movieRating(RatingAustraliaMoviesType movieRating) {
            this.movieRating = movieRating;
            this.changedFields = changedFields.add("movieRating");
            return this;
        }

        /**
         * <i>“TV rating selected for Australia”</i>
         * 
         * @param tvRating
         *            value of {@code tvRating} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder tvRating(RatingAustraliaTelevisionType tvRating) {
            this.tvRating = tvRating;
            this.changedFields = changedFields.add("tvRating");
            return this;
        }

        public MediaContentRatingAustralia build() {
            MediaContentRatingAustralia _x = new MediaContentRatingAustralia();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.mediaContentRatingAustralia";
            _x.movieRating = movieRating;
            _x.tvRating = tvRating;
            return _x;
        }
    }

    private MediaContentRatingAustralia _copy() {
        MediaContentRatingAustralia _x = new MediaContentRatingAustralia();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.movieRating = movieRating;
        _x.tvRating = tvRating;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("MediaContentRatingAustralia[");
        b.append("movieRating=");
        b.append(this.movieRating);
        b.append(", ");
        b.append("tvRating=");
        b.append(this.tvRating);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
